

-----------------
How to contribute
-----------------

If you want to contribute to this repository, feel free to fork it and open a pull request with your changes. You are also welcome to contribute to discussion in the issue tracker and of course to report issues you are facing yourself.

If you find our project helpful you can reference it in articles, posters, etc.

You can also star the project to show us that you are using it.
